######
Marian
######

.. image:: https://travis-ci.org/nebulousdog/marian.svg?branch=master
   :target: https://travis-ci.org/nebulousdog/marian
   :alt: travis-link
.. image:: https://codecov.io/gh/nebulousdog/marian/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/nebulousdog/marian
   :alt: codecov-link
.. image:: https://img.shields.io/pypi/v/marian.svg
   :target: https://pypi.org/project/marian/
   :alt: pypi-link

Find documentation at `github.com/nebulousdog/marian <https://github.com/nebulousdog/marian>`_.

*******
License
*******

MIT
